#
# spec file for package krusader
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.0.0
%define qt6_version 6.4.0

%bcond_without released
Name:           krusader
Version:        2.9.0
Release:        1.3
Summary:        Twin panel file manager for KDE Plasma and other desktops
License:        GPL-2.0-or-later
URL:            https://krusader.org/
Source0:        https://download.kde.org/stable/krusader/%{version}/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/krusader/%{version}/%{name}-%{version}.tar.xz.sig
# https://invent.kde.org/sysadmin/release-keyring/-/raw/master/keys/abikadorov@key1.asc
Source2:        krusader.keyring
%endif
Source3:        org.kde.krusader.root-mode.desktop
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  fdupes
BuildRequires:  libacl-devel
BuildRequires:  libattr-devel
BuildRequires:  cmake(KF6Archive) >= %{kf6_version}
BuildRequires:  cmake(KF6Bookmarks) >= %{kf6_version}
BuildRequires:  cmake(KF6Codecs) >= %{kf6_version}
BuildRequires:  cmake(KF6Completion) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6GuiAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6ItemViews) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6Parts) >= %{kf6_version}
BuildRequires:  cmake(KF6Solid) >= %{kf6_version}
BuildRequires:  cmake(KF6StatusNotifierItem) >= %{kf6_version}
BuildRequires:  cmake(KF6TextWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6Wallet) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt6_version}
Requires:       kio_iso = %{version}

%description
Krusader is an advanced twin panel (commander style) file manager for KDE Plasma
and other desktops in the *nix world.

%package -n kio_iso
Summary:        KIO slave to access ISO images
Provides:       kde4-kio_iso = 1.80.99
Obsoletes:      kde4-kio_iso < 1.80.99

%description -n kio_iso
KIO slave to access ISO images like zip- or tar.gz-archives in your
file-browser.

%package doc
Summary:        Krusader documentation

%description doc
Krusader is an advanced twin panel (commander style) file manager for KDE Plasma
and other desktops in the *nix world.

This package contains the krusader documentation.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name}

cp %{SOURCE3} %{buildroot}%{_kf6_applicationsdir}/

%fdupes %{buildroot}

%files
%license LICENSES/*
%doc README AUTHORS ChangeLog
%doc %lang(en) %{_kf6_mandir}/man1/krusader.1%{?ext_man}
%{_kf6_applicationsdir}/org.kde.krusader.desktop
%{_kf6_applicationsdir}/org.kde.krusader.root-mode.desktop
%{_kf6_appstreamdir}/org.kde.krusader.appdata.xml
%{_kf6_bindir}/krusader
%{_kf6_iconsdir}/hicolor/*/apps/krusader*.png
%{_kf6_kxmlguidir}/krusader/
%{_kf6_plugindir}/kf6/kio/kio_krarc.so
%{_kf6_sharedir}/krusader/
%exclude %{_kf6_htmldir}/*/krusader

%files -n kio_iso
%license LICENSES/*
%config %{_kf6_configdir}/kio_isorc
%{_kf6_plugindir}/kf6/kio/kio_iso.so

%files doc
%doc %lang(en) %{_kf6_htmldir}/en/krusader

%files lang -f %{name}.lang
%{_kf6_mandir}/*/man1/krusader.1%{?ext_man}

%changelog
* Wed Jan  1 2025 Christophe Marin <christophe@krop.fr>
- Update to 2.9.0:
  * Port to Qt 6
  * Bug fixes and minor improvements
- Allow running krusader with elevated privileges from Dolphin
  context menu
* Wed Dec 25 2024 Christophe Marin <christophe@krop.fr>
- Use xdg-su for the krusader 'root' mode. Relying on the
  X-KDE-Username won't work with plasma 6 (boo#1222490)
* Wed Nov 20 2024 Christophe Marin <christophe@krop.fr>
- Stop using the %%suse_update_desktop_file macro
* Wed Mar 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 2.8.1
  * FIXED: Flickering during folder space calculation
  * FIXED: (kde#462086) Segmentation fault when using
    CTRL+Left/Right on a panel with invalid path
  * FIXED: (kde#462307) File icons are drawn at wrong position
    if desktop scaling is active
* Tue Dec 20 2022 Christophe Marin <christophe@krop.fr>
- Update to 2.8.0.
  * Too many changes. Check the ChangeLog file for the full list
- Drop patch, merged upstream:
  * 0001-Fixed-non-working-actions-for-create-extract-archive.patch
* Wed Jun 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix the 'Compress' menu (boo#1198725, boo#1203225, kde#441376)
  * 0001-Fixed-non-working-actions-for-create-extract-archive.patch
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Spec cleanup
* Mon Aug 26 2019 wbauer@tmo.at
- Update to 2.7.2
  * FIXED: Memory leak in the Locate dialog
  * FIXED: UDSEntry::insert deprecation warnings
  * FIXED: synchronize directory window: column widths
    are incorrect (kde#167410)
  * FIXED: Context menu item "copy selected to clipboard" copies
    all result items (kde#328918)
  * FIXED: "Information - Krusader" dialog does not fit to screen
    width; text non-copyable (kde#330788)
  * FIXED: After trying to rename the file that's being updated,
    rename function stops working on any file on this tab
    (kde#392750)
  * FIXED: New Text File is created with 600 (-rw-------)
    permissions (kde#395609)
  * FIXED: Misleading ‘Created’ date in file properties
    (kde#397398)
  * FIXED: Compilation error because of QOverload usage
    (kde#405212)
  * FIXED: The list of search results doesn't get the focus
    (kde#410118)
  * FIXED: Krusader does not search correctly if the "Follow links"
    checkbox is disabled (kde#410120)
  * FIXED: Okteta support for versions >= 0.26 (due to oktetapart
    file layout change)
- Drop Prefer-to-find-oktetapart-by-desktop-file.patch, merged
  upstream
- Don't add -fpermissive to compiler options, no longer necessary
- Run spec-cleaner
* Tue Mar 12 2019 wbauer@tmo.at
- Add Prefer-to-find-oktetapart-by-desktop-file.patch to make it
  compatible with the upcoming okteta 0.26 release
* Sun Aug 12 2018 wbauer@tmo.at
- Update to 2.7.1
  * ADDED: Default shortcut for quick selection mode = Ctrl+Shift+S
  * FIXED: When calculating occupied space of ".." , krusader
    selects all directories (kde#150247)
  * FIXED: Bad default in the New Text File dialog (kde#282069)
  * FIXED: ISO files listing/extracting broken (kde#372023)
  * FIXED: Details section is empty in 'Do not know which files to
    compare.' window (kde#383567)
  * FIXED: Default mode in 'Find in folder' is not preserved
    (kde#391946)
  * FIXED: Files fed to listbox (and all other files in virt://)
    cannot be deleted (kde#394896)
  * FIXED: Enter key not working when cursor in search bar
    (kde#394939)
  * FIXED: The quicksearch bar is still opened after deleting a
    file (kde#395285)
  * FIXED: In the Manage User Actions dialog: the tab order is not
    the expected one (kde#396652)
* Mon May 14 2018 wbauer@tmo.at
- Update to 2.7.0
  * New feature: Quick Search in Bookmark menu
  * New feature: Tab pinning
  * New feature: Tooltip with file information when you hover a
    file name
  * New feature: Extended options for Tree Panel
  * New feature: Debug output option
  * Improved icon theme handling
  * Fixed 40+ issues including some regressions
- Drop patches merged upstream:
  * fix-build-with-gcc48.patch
  * Panel-fixed-actions-in-PanelContextMenu-ignored.patch
- Mark license file as %%license instead of %%doc
- Adjust file lists
* Fri Jan 12 2018 wbauer@tmo.at
- Add Panel-fixed-actions-in-PanelContextMenu-ignored.patch to fix
  the "Create New" context menu not working when the '..' entry is
  selected (boo#1075690, kde#383544)
* Mon May 15 2017 wbauer@tmo.at
- Add org.kde.krusader.root-mode.desktop, it got removed in 2.6.0
* Sun May  7 2017 wbauer@tmo.at
- Add fix-build-with-gcc48.patch to fix build on Leap 42
* Tue Apr 11 2017 wbauer@tmo.at
- Update to 2.6.0
  * FIXED: (kde#335993) save checksum does not work as expected
  * FIXED: (kde#375639) Allow typing special characters (e.g. with
    accent or acute) in search bar
  * FIXED: (kde#328068) Send SIGINT before own input command to
    embedded terminal
  * FIXED: (kde#375135) segfault on viewing html files with Generic
    viewer
  * FIXED: (kde#269820) Fullscreen terminal emulator shows empty
    window when terminal emulator was minimized
  * FIXED: (kde#374813) Multi rename with KRename does not work
    when selecting non-local files/folders (ftp, smb, virt, ...)
  * FIXED: (kde#309300) Esc as the default shortcut of "Set Focus
    to The Panel" is problematic for the embedded terminal
  * FIXED: (kde#374175) wrong date format parsing using date filter
    in search dialog
  * FIXED: (kde#293370) After a file deletion old file name is
    still shown in the status bar
  * FIXED: (kde#374322) Visually indicated shortcut ALT+o not
    working in copy/F5 and move/F6 KrDialog
  * FIXED: (kde#374238) Handle left/right arrow key press in brief
    view (previously filtered by search bar).
  * FIXED: when dragged from list panel use correct drop action if
    invoked with modifier keys
  * FIXED: added save/restore or toolbar positions in mainwindow
  * FIXED: (kde#372231) Added KDE's service actions again to
    right-click popup menu
  * ADDED: new undo action to job manager for undoing KIO job
    operations
  * FIXED: (kde#372067) Wrong path when showing non local files and
    folders from search dialog in panel
  * ADDED: job manager as replacement for queue manager. Part of
    cleaning VFS
  * FIXED: (kde#365105) Workaround for bug in KF5+QSystemTrayIcon
  * ADDED: Reimplementation of "minimize to system tray" feature.
  * FIXED: Krusader does not show the new file in a directory that
    is a symbolic link until is not refresh directory
  * FIXED: Wrong window position after restart in fluxbox
  * FIXED: Error on opening file folder after clicking on any file
    result of a remote search (FTP / smb)
  * FIXED: Terminal opens in full window
  * FIXED: copy location/path bar (feature request)
  * FIXED: krusader cannot calculate size of remote directory (ftp
    or sftp)
  * FIXED: Some files with weird characters (non UTF) cause krusader
    to miscalculate folder size
  * FIXED: No way to focus fullscreen embedded terminal emulator.
  * FIXED: Don't delete first letter in "new folder" dialog (F7)
  * FIXED: Use Shift+Delete for delete or move selected files to
    trash
  * FIXED: Dialog "File" -> "Verify checksum" improvement
  * FIXED: Option for show copy/move progress in dialog (not in
    notifications)
  * FIXED: Documents suddenly open as archives
  * CHANGED: Avoiding root mode
  * CHANGED: Duplicated tab should not be locked
  * CHANGED: New PagePanel: do not refresh until panel becomes
    visible
  * CHANGED: Change suggested command for "edit as root" user
    action to a more secure alternative
  * CHANGED: Do not configure kdesu path and remove kdesudo support
    again
  * CHANGED: Panel: Do not select .. in a filtered view if there
    are other entries
  * CHANGED: Duplicate tab settings when duplicating tabs
  * CHANGED: Some fixes and simpifying startup settings.
- Drop upstream patches:
  * krusader-2.5.0-generate-manpage.patch
  * 0001-Don-t-hardcode-appdata-location.patch
  * Remove-non-archive-mimetypes-from-krarc-archive-mime-type-list.patch
  * add-service-actions-to-right-click-popup-menu.patch
  * Handle-arrow-key-press-in-brief-view.patch
* Thu Jan  5 2017 wbauer@tmo.at
- Add Handle-arrow-key-press-in-brief-view.patch to fix the
  behavior when pressing the left/right cursor keys in brief view
  (boo#1017533, kde#374238)
* Thu Dec 22 2016 wbauer@tmo.at
- Add add-service-actions-to-right-click-popup-menu.patch to add
  KDE's service actions to the right click popup menu in krusader
  again (boo#1016980, kde#372231)
* Mon Nov 21 2016 wbauer@tmo.at
- Add Remove-non-archive-mimetypes-from-krarc-archive-mime-type-list.patch
  to fix dolphin opening e.g. LibreOffice files as archives
  (boo#1011320, kde#371765)
* Sun Oct 23 2016 hrvoje.senjan@gmail.com
- Update to 2.5.0
  * Added actions: Select files with the same name / extension
  * Changed disabled build of synchronizer by default, since it
    is unmaintained - build togglable with cmake variable
  - DENABLE_SYNCHRONIZER=true|false
  * Fixed (kde#143927) file search: "s" accelerator is doubled -
    new shortcut for "Search in" is ALT+h
  * Fixed (kde#308386) Duplicate shortcut on Search window -
    new shortcut for "Remote content search" is ALT+n
  * Fixed (kde#206926) Search doesn't work in sftp session
    (it returns too many results)
  * Fixed (kde#269542) Krusader search - Containing text
    still used when disabled
  * Fixed (kde#324737) symlinks with a target path length
    of over 255 do not work
  * Fixed (kde#189943) toolbar position settings are not remembered
  * Fixed (kde#316031) crash when loading previews
  * Fixed (kde#238672) When saving checksums fails,
    they are lost. No 2nd chance to save elsewhere.
  * Fixed (kde#315764) "application/x-source-rpm" isn't linked
    to krarc protocol by default
  * Fixed (kde#294816) Krusader needs to restart to apply
    new color scheme to panel
  * Fixed (kde#308727) external editor command isn't properly parsed
  * Fixed (kde#304233) empty main view on startup
  * Fixed (kde#315856) main view splitter sizes are not restored
  * Fixed (kde#248691) incorrect layout / wrong buttons
    in queue manager
  * Fixed (kde#315357) krarc silently fails to display
    contents of some zip files containing paths with "." as a
    path component are still not handled, but now krarc reports an
    error instead silently failing
  * Fixed (kde#310722) viewer crash when opening file
  * Fixed search result view always displays owner and group as "root"
    (may not work for remote search)
  * Fixed (kde#217711) directory chooser dialog does not allow
    to choose a directory
  * Fixed (kde#309119) Wrong "New directory" dialog behavior:
    can't clear all typed text
  * Fixed (kde#309159) Crash in video files preview on F3
  * Fixed (kde#310191) krusader still installs locolor icons
  * Fixed (kde#317510 ] icon-size-and-directory-name-mismatch
- Package ported to KF5, changed all the BuildRequires to KF5 ones
- Swap krusader-2.4.0-beta2-generate-manpage.patch for
  krusader-2.5.0-generate-manpage.patch
- Drop upstreamed bug309159.patch
- Added 0001-Don-t-hardcode-appdata-location.patch
* Tue May 26 2015 tchvatal@suse.com
- Only suggest documentation, do not recommend it.
* Wed Mar 25 2015 baiduzhyi.devel@gmail.com
- Require libktexteditor instead of kate to solve installation conflicts
  when using KF5.
* Mon Nov 12 2012 hrvoje.senjan@gmail.com
- Add bug309159.patch from upstream, to fix crashes with previewing video files
- Properly annotate previous patch (krusader-2.4.0-beta2-generate-manpage.patch)
* Sat Nov 10 2012 hrvoje.senjan@gmail.com
- Update to 2.4.0-beta3
  Changes since 2.0.0:
  * FIXED: crash when trying to open/(un)mount ejectable device via media menu
  * ADDED: options: Panel > Media Menu >
    Show Mount Path
    Show File Sytem Type
    Show Size (Always | When Device has no Label | Never)
  * ADDED: pressing CTRL+RETURN when media menu is open (un)mounts the highlighted device
  * ADDED: action: Bring Main Window to Top (global shortcut possible)
  * ADDED: option: General > Viewer/Editor > Viewer > Use Okteta As Hex Viewer
    (default: on)
  * ADDED: option: Archives > krarc > Enable Write Support
  * ADDED: splitter option: Overwrite files without confirmation
  * ADDED: action: Go to Other Panel's Directory - shortcut: CTRL+=
  * CHANGED: krarc write support is disabled by default
  * CHANGED: user action manager starts with the "Basic Properties" tab active
  * CHANGED: detailed view: "Automatically Resize Columns" setting is remembered
  * FIXED: [ 306472 ] Krusader fails to build when using clang as compiler -
    thanks to Jekyll Wu
  * FIXED: [ 308193 ] Krusader closes the search window after file editing -
    thanks to Alexander
  * FIXED: pressing the context menu key when the media menu is shown
    opens the context menu for a random item instead of the current
  * FIXED: [ 300514 ] no warning if terminal emulator can't be created
  * FIXED: [ 303209 ] passwords for remote connections are stored in config
    NOTE: passwords already stored in krusaderrc may still be left
  * FIXED: [ 280946 ] viewer: incorrect tab's file names when moving tabs
  * FIXED: user actions: "run in the embedded terminal emulator" setting is not saved
  * FIXED: mountman: mount list is not refreshed if /etc/mtab is a symlink to /proc/mounts
  * FIXED: [ 148866 ] create new directory: spaces are stripped out
  * FIXED: [ 305069 ] list panel is not autoscrolled to the cursor (in brief view)
  * FIXED: [ 173690 ] file ACLs are not displayed correctly in properties dialog
  - thanks to Eugeny Shkrigunov
  * FIXED: It is impossible to select a non-default folder in the search dialog
  * FIXED: splitter overwrites files without confirmation
  * FIXED: [ 274483 ] crash when selecting items from popup-menu
  * FIXED: [ 285778 ] View or edit files doesn't work
  * FIXED: viewer tries to load obsolete libkhexedit2 part as hex viewer -
    use okteta part instead
  * FIXED: crash when trying to view files with embedded KOrganizer part
    (avoids KOrganizer bug 205713)
  * FIXED: "apply settings to other tab" action doesn't apply icon size
  * FIXED: [ 198996 ] crash when closing viewer
  * FIXED: [ 294501 ] toolbar "equal" has no shortcut
  * FIXED: [ 108892 ] "Combine Files" overwrites existing target file without confirmation
  * FIXED: Queue manager closed when any of the queues finished
  * FIXED: [ 300922 ] crash when pause sftp transfer via queue on quit
  * FIXED: [ 271265 ] krusader should search for kdesu executable in /usr/lib{64,}/kde4/libexec/
  - thanks to Anssi Hannula / Ahmad Samir
  * FIXED: [ 290304 ] Panel option "always sort dirs by name" doesn't work
  * FIXED: [ 297926 ] state of the menu item 'Show hidden files' and the current setting is different
  * FIXED: [ 234296 ] crash when closing disk usage view
  * FIXED: [ 296718 ] execution of files that have spaces in their path doesn't work anymore
  * FIXED: [ 294618 ] using "open with" on video files
    causes their thumbnails to be created, even when not needed
  * FIXED: root mode action doesn't work if a panel url contains spaces
  * FIXED: relative url completion in address-bar only works in home dir
  * FIXED: [ 242566 ] Cannot F3-View .vcf vCard files
  * FIXED: Root action (which opens the root dir of the local filesystem)
    is disabled in the root dir of nonlocal filesystems
  * FIXED: when cutting to clipboard from virt:/ the virtual entries are immediately removed
  * FIXED: Unselecting files before copy/move operation doesn't work for copy&paste
  * FIXED: [ 277259 ] Unselecting files before copy/move operation doesn't work in the same panel
    this also fixes the selection of the other panel being cleared instead
  * FIXED: [ 276310 ] crash when trying to delete already deleted file
  * FIXED: [ 277578 ] Crash on cancelling calculation of occupied space on smb share
  * FIXED: krusader hangs for some time when opening a bz2(and possibly gzip)-compressed archive
  * FIXED: loading defaults on the Panel page in Konfigurator has no effect
  * FIXED: changes to "Show new/close tab buttons" don't take effect immediately
  * FIXED: when options requiring a gui restart are changed, the panel history is lost
  * FIXED: [ 277838 ] Swap Panels no longer works
  * ADDED: option: Panel > Status/Totalsbar > Show space information
  * ADDED: Konfigurator: reset button
  * ADDED: option: Startup > User Interface > Show actions toolbar
  * ADDED: options: Panel > Layout: "Compact", "Classic"
  * ADDED: mountman gui option: Show only removable devices
  * ADDED: tabs have close buttons
  * ADDED: reset button for filter dialog
  * ADDED: option: Panel > Operation > Filter dialog remembers settings
  * ADDED: tabs can be dragged to the other side
  * ADDED: action: Move Current Tab to Other Side - shortcut: CTRL + SHIFT + O
  * ADDED: view: iconsizes 64, 128, 256
  * ADDED: history is saved/restored
  * ADDED: action: Restore Selection
  * ADDED: option: Panel > Operation > Unselect files before copy/move
  * ADDED: support for xz archives
  * CHANGED: new default panel layout
  * CHANGED: option: Panel > View > Show previews -> Show previews by default
  * CHANGED: removed option "Show free disk space in the Totalsbar"
    since that setting is controlled by the layout chosen in Panel >
    Layout
  * CHANGED: removed option "Preserve Attributes" - KIO always preserves
    Attributes
  * CHANGED: option: Panel > Filelist icon size -> Default icon size
  * CHANGED: quickfilter follows case sensivity setting of quicksearch
  * CHANGED: quickfilter expands wildcards
  * CHANGED: duplicate tab / open in new tab:
    create the new tab next to the current one.
  * CHANGED: filter settings are saved/restored individually for each tab.
  * CHANGED: filter settings are remembered when changing view type
  * CHANGED: All view settings are saved/restored individually for each tab.
  * FIXED: [ 3222819 (sf.net) ] Alt-Enter is not showing selected files'
    properties
  * FIXED: [ 274083 ] Search results list shows wrong extension when dir path
    has a dot in it
  * FIXED: [ 262761 ] krusader crashed on viewing text file with internal viewer
    this was probably already fixed in 2.3.0-beta1
  * FIXED: [ 229489 ] Seg fault moving ISO image files from USB Flash drive to
    USB SATA HD
  - thanks to Anssi Hannula
  * FIXED: mountman gui might add the same mountpoint to the list multiple times
  * FIXED: [ 3044425 (sf.net) ] Desktop freeze when opening a context menu
  * FIXED: [ 217203 ] Krusader crashed when accessing sftp after resume from
    sleep
  * FIXED: [ 243716, 270605, 270588 ] crash when moving files
  * FIXED: [ 256794 ] crash when file is deleted while a preview is being loaded
    for it (and it is the only file for which a preview is being loaded)
  * FIXED: [ 274732 ] Weird functionality after "directory doesn't exist"
  * FIXED: [ 3216624 (sf.net) ] Krusader saves newly created files with
    incorrect permissions
  * FIXED: [ 2773302 (sf.net) ] krarc can't handle brackets in file paths inside
    ZIP archive
  * FIXED: [ 272876, 274269 ] crash when refreshing view
  * FIXED: [ 3191155 (sf.net) ] Moving a symbolic link changes attributes of
    target file
  * FIXED: [ 2998795 (sf.net) ] "Show actions toolbar" setting is not saved
  * FIXED: Url commandline argument opens a new tab instead of switching to an
    existing one
  * FIXED: root mode action does not work with newer versions of kdesu,
    thanks to CyberCastle
  * FIXED: switching tabs sometimes doesn't switch the panel
  * FIXED: [ 3004510 (sf.net) ] Double-clicking executables start in
    ~/Documents folder
  * FIXED: [ 2996188 (sf.net) ] relative path for custom folder icon doesn't
    work
  * FIXED: [ 2915020 (sf.net) ] wrong icon for directory symlink
  * FIXED: when switching tabs, sometimes the new tab isn't set active
  * FIXED: [ 263253 ] View displays wrong total size in some circumstances.
  * FIXED in 2.3.0-beta1, but not recorded in Changelog at release time:
    [ 259495 ] crash when closing search dialog
  * ADDED: option: Panel > General > Flat Origin Bar
  * ADDED: option: Panel > Buttons > Toolbar buttons have icons
  * ADDED: listpanel buttons: Back, Forward
  * ADDED: options: Panel > Layout >
    Layout / Frame Color / Frame Shape / Frame Shadow
  * ADDED: QuickFilter - default shortcut: CTRL+i
  * ADDED: option: Panel > View > Show directories first
  * ADDED: actions: Back/Forward in history
  * ADDED: action: Set Focus to the Panel - shortcut: ESC
  * ADDED: actions: Move Focus Up/Down - shortcut: CTRL+SHIFT+Up/Down
  * ADDED: selection dialog option: Apply selection to directories
  * ADDED: option: Startup > User Interface > Update default panel settings
  * ADDED: dbus interface: org.krusader.Instance.openUrl(QString url)
  * ADDED: search dialog > feed to listbox:
    search parameters are saved as metadata in the virtual fs and
    displayed in panel's statusbar
  * ADDED: filter option: Apply filter to directories
  * ADDED: action: view > Apply settings to other tabs
  * ADDED: action: view > Save settings as default (for new instances of this
    view type)
  * ADDED: option: Panel > View > Locale aware sorting
  * CHANGED: Media Button shows Solid Icon for currently opened device
  * CHANGED: Removed options Panel > General > Status/Totalsbar >
    Statusbar Frame / Statusbar Background / Show Statusbar /
    Show Totalsbar. They are customizable in layout.xml.
  * CHANGED: Use KrView for displaying search results,
    which is much faster than the previously used QTreeWidget.
  * CHANGED: Removed default shortcuts for the Left/Right Bookmarks actions,
    as they conflict with the Back/Forward actions.
  * CHANGED: After failed refresh, only focus location bar if the url was entered
    manually.
  * CHANGED: Removed default shortcut for 'Cancel Refresh of View' as it conflicts
    with the 'Set Focus to the Panel' action. Unless a shortcut is
    assigned manually, ESC cancels the refresh when the panel is focused.
  * CHANGED: Konfigurator: "apply" takes effect immediately.
  * CHANGED: Url commandline argument: if there is already a tab open with that
    url, it is activated, otherwise a new tab is opened in the active
    panel.
  * FIXED: When trying to close Konfigurator but canceling the
    "Apply changes ?" dialog, Konfigurator it is closed anyway.
  * FIXED: [ 3073211 ] Wrong quoting when opening file in external editor
  * FIXED: [ 3059457 ] new panel uses default columns instead of configured
    ones
  * FIXED: [ 2898151 ] also in view-mode (F3) possible to edit, thanks to Kevin
    Kofler
  * FIXED: panelpopup viewer: error messageboxes when file cannot be displayed
  * FIXED: [ 2981303 ] Viewer/editor unused submenu Game, thanks to Kevin
    Kofler
  * FIXED: regression making single-click mode unusable, thanks to Kevin Kofler
  * FIXED: [ 3003338 ] Rename selects extension regression, thanks to Kevin
    Kofler
  * FIXED: [ 2980201 ] KrViewer doesn't handle binary files well (this fix
    works only for local files !)
  * FIXED: "sort by" useractions change sorting direction randomly
  * FIXED: [ 3028599 ] Sorting criteria is not saved at exit
  * FIXED: [ 2949337 ] splitter ui bug
  * FIXED: [ 2843749 ] view item is deselected when updated
  * FIXED: [ 268037 (bugs.kde.org) ] brief view: mouse wheel doesn't work
  * FIXED: brief view: mouse selection doesn't work in columns > columns per
    page
  * FIXED: selecting a bigger number of files is very slow
  * FIXED: [ 2969403 ] KrViewer shows old file content if file is overwritten,
    thanks to Kevin Kofler
  * FIXED: [ 246424 (bugs.kde.org) ] krusader tries to load WHOLE big file into
    memory on F3
  * FIXED: [ 2154760 ] Krusader erases files when opening for editing
  * FIXED: changing sort direction is slow
  * FIXED: [ 3015094 ] krusader doesn't exit at closing the application
  * FIXED: right clicking on media button doesn't work
  * FIXED: tabs were no longer movable, thanks to Victor (kernel_daemon)
  * FIXED: 3 valgrind fixes by Alexander Stein
  * FIXED: viewer would show empty menus, thanks to CtHx
  * FIXED: crash when changing view type
  * ADDED: option: Panel > General > Tabs > Show new/close tab buttons
  * ADDED: options: Panel > Buttons > Show Media/History/Bookmarks Button
  * ADDED: options: Panel > General > Status/Totalsbar settings >
    Show Statusbar, Show Totalsbar, Show Size In Bytes,
    Show free disk space in the Totalsbar
  * ADDED: option: Look&Feel > Quicksearch > "Up/Down cancels Quicksearch"
  * ADDED: dbus interface: org.krusader.PanelManager.newTab(QString url) /
    newTabs(QStringList)
  * ADDED: url command-line argument
  * ADDED: action "Show View Options Menu"
  * ADDED: detailed view context-menu option "Automatically Resize Columns"
  * ADDED: action "cancel refresh" triggered by ESC by default
  * ADDED: change icon size individually per view
  * ADDED: thumbnails - toggleable by mainmenu > view > Show Previews
  * ADDED: 128x128 pixel versions of the application icon, needed by Mac OS X
  * ADDED: Konfigurator options: Look&Feel > Panel >
    Status/Totalsbar settings > Draw frame / Fill background
  * ADDED: Konfigurator option: Colors > Colors > Other > Statusbar
  * ADDED: Konfigurator option: Look&Feel > Panel > Panel layout >
    Quicksearch position / Tab Bar position
  * ADDED: buttons "(un)mount" and "eject" in mountman gui
  * ADDED: KMountMan::removable(), KMountMan::networkFilesystem()
  * CHANGED: reorganize Konfigurator: "Look & Feel" page becomes "Panel" /
    move several options to new places
  * CHANGED: when open/refresh of a dir fails, don't annoy the user with a message
    box, but display the error embedded into the panel
  * CHANGED: icon size, icons/previews on/off are set separately per view type
  * CHANGED: dim icons in unfocused panel (if dim colors is activated)
  * CHANGED: mountman gui: retrieve icons from Solid
  * CHANGED: mountman gui: change mount check interval from 3000 to 500 ms
  * CHANGED: mountman gui: current selection persists refresh of mountlist,
    mountlist is focused after refresh
  * CHANGED: dont't execute a process if the correct working dir cannot be set
  * CHANGED: dont't retrieve working dir of the cmdline from the label which might
    get truncated - store it in a string instead
  * FIXED: brief view: clicking on the space below a column selects the first
    item of the next column
  * FIXED: if refresh has failed, the origin bar is focused even if the panel is
    not active
  * FIXED: if the path of an inactive panel changes, the embedded cmdline is set
    to that path
  * FIXED: useraction commands, or those entered in the embedded cmdline, are
    sometimes not executed in the correct working dir
  * FIXED: when multiple commands are entered in the embedded cmdline or a
    useraction, and execution mode is set to terminal, only the first
    command is executed in a new terminal and the others in the same
    terminal (if any) as krusader
  * FIXED: commands entered via command line are mixed up with history
  * FIXED: [ 2790819, 2892768, 2915192 ] Can't resize columns properly
  * FIXED: disk usage dialog layout problem
  * FIXED: [ 2907607 ] crash while closing
  * FIXED: if a panel is focused by clicking on the header, the colors/actions
    are not updated
  * FIXED: mountman: unmounting is not possible if currently opened dir is below
    the mountpoint
  * FIXED: [ 2860400 ] Drag'n'drop to kmail broken
  * FIXED: [ 2904850 ] panels are not repainted
  * FIXED: deadlock when trying to display error message after failed mount
  * FIXED: [ 2858133 ] wrong background color in listviews
  * ADDED: file regex in quick search, thanks to GregC
  * ADDED: lister: a fast text/hex viewer for Krusader
  * ADDED: service menu, thanks to Tomasz Kalkosinski
  * ADDED: queued packing / unpacking
  * ADDED: lock tabs, close inactive tabs, close duplicated tabs
  * ADDED: better trash integration
  * CHANGED: the packer/unpacker/archive tester are job based now
  * CHANGED: the old views were replaced by the interviews
  * FIXED: [ 2857663 ] deadlock when trying to display error message after
    failed unmount
  * FIXED: problem with autorefresh in the new interviews
  * FIXED: [ 2609505 ] problem with directory refresh
  * FIXED: [ 2793916 ] KHistoryComboBox content can change the window width
  * FIXED: [ 2805624 ] ctrl-left/right arrow with locked tabs on the other panel
  * FIXED: panels sometimes lose focus
  * FIXED: directory compare modes don't work
  * FIXED: [ 2609483 ] unpacking to directories with international characters
* Mon Nov 21 2011 ctrippe@opensuse.org
- Require kate as this is needed at runtime for the view and edit
  dialog (bnc#712179)
* Fri Sep 16 2011 toddrme2178@gmail.com
- Added %%kde4_runtime_requires macro (fix for RPMLINT warning)
- Fixed self-obsoletes (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Thu Aug 25 2011 idonmez@novell.com
- Add krusader-link-solid.patch: explicitly link to solid libs
* Wed Jun 15 2011 coolo@novell.com
- add -fpermissive to pass old code in new gccs
* Thu Sep  9 2010 coolo@novell.com
- fix compilation with latest libqt4
* Mon Apr 19 2010 javier@opensuse.org
- added pt and pt_BR translations for the browse iso service
  menu
* Mon Apr 19 2010 wstephenson@novell.com
- Hungarian translation
* Sat Apr 10 2010 javier@opensuse.org
- added kr, uk and zh_TW, translations for the browse iso service
  menu
* Thu Apr  8 2010 javier@opensuse.org
- added bg, ca, da, it, lv, nb, nl, ru, sk and wa translations for
  the browse iso service menu
* Sun Mar 28 2010 javier@opensuse.org
- added browse iso service menu
* Mon Aug 10 2009 beineri@opensuse.org
- fix menu category of Krusader root modus entry
* Mon May 18 2009 tittiatcoke@gmail.com
- added patch to compile correctly with GCC 4.4
* Sat May  2 2009 dmueller@suse.de
- review/merge to openSUSE Factory
* Sat Apr 18 2009 bitshuffler #suse@irc.freenode.org
- Updated to 2.0.0
* Sat Mar 21 2009 beineri@opensuse.org
- added SVN trunk diff:
  * archive dialog now remembers compression level
  * changed default Alt+letter shortcuts, see details in SVNNEWS
  * initial Konfigurator size is now 900x680
  * view properties for detailed/brief/interviews are merged
  * several bugfixes
* Fri Mar  6 2009 wstephenson@suse.de
- make it compile vs Qt 4.5
* Sun Feb  1 2009 dmueller@suse.de
- rename sr@Latn to sr@latin1
* Mon Dec 29 2008 stbinner@suse.de
- update to 2.0.0 Beta 2 release:
  * Shortcuts: copy by queue (SHIFT+F5), move by queue (SHIFT+F6)
  * Krusader support for tar.lzma
* Mon Dec  1 2008 dmueller@suse.de
- add provides/obsoletes for kde4-kio_iso
* Sat Nov 22 2008 stbinner@suse.de
- update to SVN version (even more beta 2):
  * Possibility to choose one of five sorting methods
  * Compare by content for search / locate
  * New mouse selection mode
  * Evolution can be used as the default e-mail sender
  * Enqueue operation for copy / move
  * Upated translations for German, Dutch, Czech and Korean
* Mon Sep 22 2008 stbinner@suse.de
- update to SVN version (almost beta 2):
  * Manage Useractions: "Run in embedded terminal emulator"
  * Manage Useractions: added checkbox "enabled"
  * Root mode Krusader configuration, use eg. gksu instead of kdesu
* Mon Jul 21 2008 anschneider@suse.de
- Fix starting krusader in root-mode from tools menu.
* Wed Jul 16 2008 anschneider@suse.de
- updated to version 2.0.0 beta1:
  * Ported to KDE4 not using any of the Qt3 support libs
  * Experimental support for the Windows platform
  * Send emails with Thunderbird
  * Attach multiple files to emails
  * Submenus for categories in UserAction menu and context menu
  * Select encoding in content search and krarc
  * New synchronizer shortcuts
* Sat Mar 22 2008 stbinner@suse.de
- update to version 1.90.0:
  * addition of many (JavaScript) user actions, midnight commander
    keymap and new color schemes
  * dropped patches that have been merged upstream
* Thu Oct 25 2007 dmueller@suse.de
- fix build with gcc 4.3
* Sun Aug 19 2007 stbinner@suse.de
- fix build on 10.0
* Sun Jul 22 2007 stbinner@suse.de
- update to version 1.80.0:
  * Full support for ACL permissions like properties, preserve
    attributes, synchronizer and other
  * Many terminal emulator enhancements bringing new functions,
    new usages and new look
  * Many improvements of the UserAction system
  * Countless usability enhancements, especially in Konfigurator
    and the heavily reordered menubar
  * Comparing in the synchronizer interface and parallel threading
    over slower servers
  * Atomic extensions and ability to rename filename, w/o extension
  * Many archive enhancements like handling packing in background,
    encryption support, multiple volume archives, compress level
* Fri Jun  1 2007 coolo@suse.de
- move kde_post_install
* Fri Mar  9 2007 stbinner@suse.de
- fix build (new icon location check)
* Fri Feb  2 2007 stbinner@suse.de
- fix changes file not incremental
* Tue Jan  9 2007 stbinner@suse.de
- fix more comparison against string literal (#231711)
* Sat Dec  9 2006 dmueller@suse.de
- fix comparison against string literal (#226876)
* Fri Dec  1 2006 stbinner@suse.de
- fix crashes when viewing file properties (#223673)
* Fri Nov 24 2006 stbinner@suse.de
- fix "ISO9660 View" action in Konqueror's context menu (#223590)
* Wed Sep 27 2006 stbinner@suse.de
- update to 1.70.1
  * fixed sometimes passwords stored in cleartext in bookmarks.xml
  * fixed several memory access faults discovered with valgrind
  * added Turkish translatio
- split off kio_iso package
* Fri Sep  8 2006 stbinner@suse.de
- fix duplicate parameter (#177156)
* Wed Jun 21 2006 dmueller@suse.de
- fix build with gcc >= 4.2.0
* Tue Jun 20 2006 dmueller@suse.de
- build parallel
* Tue May 30 2006 adrian@suse.de
- fix build for < 10.1
* Tue Feb 14 2006 mrueckert@suse.de
- Update to 1.70.0 [#116456]
- removed all previous patches
- added krusader-1.70.0_compilerwarnings.patch
  fixes a few "non void functions without return statement"
  warnings
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Oct 30 2005 stbinner@suse.de
- update to version 1.60.1
* Wed May 25 2005 adrian@suse.de
- fix build for gcc 4
* Thu Apr 14 2005 adrian@suse.de
- update to version 1.60.0
* Thu Feb 17 2005 adrian@suse.de
- menu entry moved to xdg dir
* Fri Feb 11 2005 coolo@suse.de
- update to version 1.51 and replay history of the last 3 years
* Sun Aug 18 2002 adrian@suse.de
- update to version 1.1
  (hopefully fixes the reported random crashes for some users)
* Fri May 24 2002 coolo@suse.de
- update_admin
* Tue Apr 16 2002 adrian@suse.de
- update to 1.02 (official compile fix)
* Sat Apr 13 2002 adrian@suse.de
- update to 1.01 (KDE3 support)
- gcc 3 fixes
* Wed Jan  2 2002 adrian@suse.de
- update to final 1.00
* Wed Dec 19 2001 adrian@suse.de
- update to RC1
* Thu Dec  6 2001 adrian@suse.de
- update to version 0.99
* Mon Nov 12 2001 ro@suse.de
- fix for automake 1.5
* Fri Nov  9 2001 adrian@suse.de
- use kde2-devel-packages
* Mon Aug 13 2001 ro@suse.de
- changed neededforbuild <sp_libs> to <sp-devel>
* Fri Aug 10 2001 adrian@suse.de
- autoconf 2.52 fixes
* Tue Jul 24 2001 adrian@suse.de
- New version 0.95.1
* Sun Jul 15 2001 @suse.de
- New version 0.93.1
* Thu Jun 28 2001 adrian@suse.de
- autoconf 2.50 fixes
* Mon Apr 30 2001 adrian@suse.de
- fix install pathes
* Mon Apr 30 2001 adrian@suse.de
- Spec file created from krusader-0.79.tar.bz2 by autospec
* Thu Apr 19 2001 ro@suse.de
- added openssl-devel to neededforbuild
* Tue Mar 27 2001 ro@suse.de
- changed neededforbuild <docbkdsl> to <docbook-dsssl-stylesheets>
* Sun Mar 18 2001 ro@suse.de
- fixed neededforbuild
* Tue Mar 13 2001 ro@suse.de
- changed neededforbuild <docbk30> to <docbook_3>
* Sun Mar  4 2001 adrian@suse.de
- update to 0.79-1
* Thu Mar  1 2001 ro@suse.de
- added fam to neededforbuild
* Mon Jan  1 2001 adrian@suse.de
- update to 0.75-1
* Fri Dec  1 2000 kukuk@suse.de
- Remove duplicate entries
* Fri Dec  1 2000 kukuk@suse.de
- export KDEDIR
- Fix filelist
* Fri Nov 17 2000 ro@suse.de
- fixed neededforbuild: += libmng-devel
* Fri Nov 10 2000 adrian@suse.de
- initial package
